Attribute VB_Name = "Module1"
' ***************************************************************************************
'    NI-TClk
'
'    National Instruments library for TClk synchronization
'
'    Copyright (c) National Instruments 2003.  All Rights Reserved.
' ****************************************************************************************
Option Explicit
Option Base 0

' ****************************************************************************************
' ---------------------------- Attribute Definitions -------------------------------------
' ****************************************************************************************

Public Const NITCLK_ATTR_SYNC_PULSE_SOURCE = 1
Public Const NITCLK_ATTR_EXPORTED_SYNC_PULSE_OUTPUT_TERMINAL = 2
Public Const NITCLK_ATTR_START_TRIGGER_MASTER_SESSION = 3
Public Const NITCLK_ATTR_REF_TRIGGER_MASTER_SESSION = 4
Public Const NITCLK_ATTR_SCRIPT_TRIGGER_MASTER_SESSION = 5
Public Const NITCLK_ATTR_PAUSE_TRIGGER_MASTER_SESSION = 6
Public Const NITCLK_ATTR_SYNC_PULSE_CLOCK_SOURCE = 10
Public Const NITCLK_ATTR_SAMPLE_CLOCK_DELAY = 11

' ****************************************************************************************
' -------------------------- Library Function Declarations -------------------------------
' ****************************************************************************************

Public Declare Function niTClk_ConfigureForHomogeneousTriggers Lib "niTClk.dll" (ByVal sessionCount As Long, ByRef sessions() As Long) As Long

Public Declare Function niTClk_Synchronize Lib "niTClk.dll" (ByVal sessionCount As Long, ByRef sessions() As Long, ByVal minTime As Double) As Long

Public Declare Function niTClk_Initiate Lib "niTClk.dll" (ByVal sessionCount As Long, ByRef sessions() As Long) As Long

Public Declare Function niTClk_WaitUntilDone Lib "niTClk.dll" (ByVal sessionCount As Long, ByRef sessions() As Long, ByVal timeout As Double) As Long

Public Declare Function niTClk_GetExtendedErrorInfo Lib "niTClk.dll" (ByVal errorString As String, ByVal errorStringSize As Long) As Long


' --- Advanced Functions

Public Declare Function niTClk_IsDone Lib "niTClk.dll" (ByVal sessionCount As Long, ByRef sessions() As Long, ByRef done As Integer) As Long


' ------ Set Attribute

Public Declare Function niTClk_SetAttributeViString Lib "niTClk.dll" (ByVal session As Long, ByVal channelName As String, ByVal attributeId As Long, ByVal value As String) As Long

Public Declare Function niTClk_SetAttributeViSession Lib "niTClk.dll" (ByVal session As Long, ByVal channelName As String, ByVal attributeId As Long, ByVal value As Long) As Long

Public Declare Function niTClk_SetAttributeViReal64 Lib "niTClk.dll" (ByVal session As Long, ByVal channelName As String, ByVal attributeId As Long, ByVal value As Double) As Long


' ------ Get Attribute

Public Declare Function niTClk_GetAttributeViString Lib "niTClk.dll" (ByVal session As Long, ByVal channelName As String, ByVal attributeId As Long, ByVal bufSize As Long, ByVal value As String) As Long

Public Declare Function niTClk_GetAttributeViSession Lib "niTClk.dll" (ByVal session As Long, ByVal channelName As String, ByVal attributeId As Long, ByRef value As Long) As Long

Public Declare Function niTClk_GetAttributeViReal64 Lib "niTClk.dll" (ByVal session As Long, ByVal channelName As String, ByVal attributeId As Long, ByRef value As Long) As Long


' ****************************************************************************************
' ------------------------ Error And Completion Codes ------------------------------------
' ****************************************************************************************

Public Const NITCLK_SUCCESS = 0


Public Const NITCLK_ERROR_START_TRIG_MASTER_DOES_NOT_SUPPORT_TCLK = -250001
Public Const NITCLK_ERROR_REF_TRIG_MASTER_DOES_NOT_SUPPORT_TCLK = -250002
Public Const NITCLK_ERROR_SCRIPT_TRIG_MASTER_DOES_NOT_SUPPORT_TCLK = -250003
Public Const NITCLK_ERROR_PAUSE_TRIG_MASTER_DOES_NOT_SUPPORT_TCLK = -250004
Public Const NITCLK_ERROR_START_TRIG_MASTER_DOES_NOT_SUPPORT_TCLK_FOR_LABVIEW = -250005
Public Const NITCLK_ERROR_REF_TRIG_MASTER_DOES_NOT_SUPPORT_TCLK_FOR_LABVIEW = -250006
Public Const NITCLK_ERROR_SCRIPT_TRIG_MASTER_DOES_NOT_SUPPORT_TCLK_FOR_LABVIEW = -250007
Public Const NITCLK_ERROR_PAUSE_TRIG_MASTER_DOES_NOT_SUPPORT_TCLK_FOR_LABVIEW = -250008
Public Const NITCLK_ERROR_CHAN_NAME_NOT_EMPTY = -250009
Public Const NITCLK_ERROR_REF_CLK_RATE_ZERO = -250010
Public Const NITCLK_ERROR_REF_CLK_RATE_NEGATIVE = -250011
Public Const NITCLK_ERROR_UNEQUAL_REF_CLK_RATES = -250012
Public Const NITCLK_ERROR_MIN_TCLK_PERIOD_NOT_SUPPORTED = -250013
Public Const NITCLK_ERROR_REF_CLK_SRC_NONE = -250014
Public Const NITCLK_ERROR_EXT_SAMP_CLK_RATE_NOT_ALSO_INT = -250015
Public Const NITCLK_ERROR_CANNOT_FIND_COMMON_TCLK_PERIOD = -250016
Public Const NITCLK_ERROR_INCONSISTENT_SYNC_PULSE_CLK_SRC = -250017
Public Const NITCLK_ERROR_INCONSISTENT_REF_CLK_SRC = -250018
Public Const NITCLK_ERROR_NO_START_TRIGS_CONFIGURED_ONE_OR_MORE_MASTERS = -250019
Public Const NITCLK_ERROR_NO_REF_TRIGS_CONFIGURED_ONE_OR_MORE_MASTERS = -250020
Public Const NITCLK_ERROR_NO_PAUSE_TRIGS_CONFIGURED_ONE_OR_MORE_MASTERS = -250021
Public Const NITCLK_ERROR_NO_SCRIPT_TRIGS_CONFIGURED_ONE_OR_MORE_MASTERS = -250022
Public Const NITCLK_ERROR_MULTIPLE_START_TRIG_MASTERS = -250023
Public Const NITCLK_ERROR_TIMEOUT_NOT_SUPPORTED = -250024
Public Const NITCLK_ERROR_OP_NOT_DONE_WITHIN_TIMEOUT = -250025
Public Const NITCLK_ERROR_MULTIPLE_SESSIONS_EXPORT_SYNC_PULSE = -250026
Public Const NITCLK_ERROR_SESSION_NOT_SUPPORTED = -250027
Public Const NITCLK_ERROR_ZERO_SESSIONS = -250028
Public Const NITCLK_ERROR_SESSIONS_ARRAY_NULL = -250029
Public Const NITCLK_ERROR_SESSION_SPECIFIED_TWICE = -250030
Public Const NITCLK_ERROR_TWO_SESSIONS_FOR_ONE_DEVICE = -250031
Public Const NITCLK_ERROR_SESSION_NOT_VALID = -250032
Public Const NITCLK_ERROR_COMMIT_FAILED = -250033
Public Const NITCLK_ERROR_INITIATE_FAILED = -250034
Public Const NITCLK_ERROR_IS_DONE_FAILED = -250035
Public Const NITCLK_ERROR_NULL_ERROR_STRING = -250036
Public Const NITCLK_ERROR_ZERO_START_TRIG_MASTERS = -250037
Public Const NITCLK_ERROR_ATTRIBUTE_ID_NOT_SUPPORTED = -250038
Public Const NITCLK_ERROR_GET_ATTRIBUTE_FUNCTION_NOT_SUPPORTED_DUE_TO_DATA_TYPE = -250039
Public Const NITCLK_ERROR_SET_ATTRIBUTE_FUNCTION_NOT_SUPPORTED_DUE_TO_DATA_TYPE = -250040
Public Const NITCLK_ERROR_GET_ATTRIBUTE_NOT_SUPPORTED = -250041
Public Const NITCLK_ERROR_SET_ATTRIBUTE_NOT_SUPPORTED = -250042
Public Const NITCLK_ERROR_INSTRUMENT_DRIVER_CALL_FAILED = -250043
Public Const NITCLK_ERROR_EXT_SAMP_CLK_RATE_NOT_ABOVE_ZERO = -250044
Public Const NITCLK_ERROR_EXT_SAMP_CLK_RATES_UNEQUAL = -250045
Public Const NITCLK_ERROR_TRIG_MASTER_SESSION_NO_LONGER_VALID = -250046
Public Const NITCLK_ERROR_MULTIPLE_SESSIONS_EXPORT_ONBOARD_REF_CLK = -250047
Public Const NITCLK_ERROR_SAMP_CLK_DELAY_NOT_SUPPORTED = -250048
Public Const NITCLK_ERROR_ONE_START_TRIG_CONFIGURED_ONE_OR_MORE_MASTERS = -250049
Public Const NITCLK_ERROR_ONE_REF_TRIG_CONFIGURED_ONE_OR_MORE_MASTERS = -250050
Public Const NITCLK_ERROR_ONE_PAUSE_TRIG_CONFIGURED_ONE_OR_MORE_MASTERS = -250051
Public Const NITCLK_ERROR_ONE_SCRIPT_TRIG_CONFIGURED_ONE_OR_MORE_MASTERS = -250052
Public Const NITCLK_ERROR_ALL_BUT_ONE_START_TRIG_CONFIGURED_AND_NONE_TRIG_NOT_MASTER = -250053
Public Const NITCLK_ERROR_ALL_BUT_ONE_REF_TRIG_CONFIGURED_AND_NONE_TRIG_NOT_MASTER = -250054
Public Const NITCLK_ERROR_ALL_BUT_ONE_PAUSE_TRIG_CONFIGURED_AND_NONE_TRIG_NOT_MASTER = -250055
Public Const NITCLK_ERROR_ALL_BUT_ONE_SCRIPT_TRIG_CONFIGURED_AND_NONE_TRIG_NOT_MASTER = -250056
Public Const NITCLK_ERROR_NUM_SESSIONS_START_TRIG_CONFIGURED = -250057
Public Const NITCLK_ERROR_NUM_SESSIONS_REF_TRIG_CONFIGURED = -250058
Public Const NITCLK_ERROR_NUM_SESSIONS_PAUSE_TRIG_CONFIGURED = -250059
Public Const NITCLK_ERROR_NUM_SESSIONS_SCRIPT_TRIG_CONFIGURED = -250060
Public Const NITCLK_ERROR_SAMP_CLK_RATE_TOO_LOW = -250061
Public Const NITCLK_ERROR_SAMP_CLK_DELAY_NOT_SUPPORTED_FOR_ACQ_SESSIONS = -250062
Public Const NITCLK_ERROR_SAMP_CLK_DELAY_NOT_SUPPORTED_FOR_EXT_SAMP_CLK = -250063
Public Const NITCLK_ERROR_SAMP_CLK_DELAY_NOT_SUPPORTED_FOR_EXT_SAMP_CLK_TIMEBASE = -250064
Public Const NITCLK_ERROR_MORE_THAN_ONE_REF_TRIG_MASTER = -250065
Public Const NITCLK_ERROR_ACTIVE_CHANNELS_NOT_SUPPORTED_FOR_LABVIEW = -250066
Public Const NITCLK_ERROR_ACTIVE_CHANNELS_FOR_SCRIPT_TRIGGER_MASTER_FOR_LABVIEW = -250067
Public Const NITCLK_ERROR_VALUE_IS_NULL = -250068
Public Const NITCLK_ERROR_CHANNEL_NAME_FOR_SCRIPT_TRIGGER_MASTER = -250069
Public Const NITCLK_ERROR_INCOMPATIBLE_VERSIONS_OF_NITCLK_AND_INSTRUMENT_DRIVER = -250070
Public Const NITCLK_ERROR_INCOMPATIBLE_VERSIONS_OF_NITCLK_AND_2_INSTRUMENT_DRIVERS = -250071
Public Const NITCLK_ERROR_EXT_SAMP_CLK_AND_OR_SAMP_CLK_TIMEBASE_RATE_UNMATCHED = -250072
Public Const NITCLK_ERROR_INVALID_ORDERING_OF_DEVICES_LIST = -250073

Public Const NITCLK_WARNING_COMMIT_RETURNED_WARNING = 250000
Public Const NITCLK_WARNING_INITIATE_RETURNED_WARNING = 250001
Public Const NITCLK_WARNING_IS_DONE_RETURNED_WARNING = 250002
Public Const NITCLK_WARNING_STRING_TRUNCATED_TO_FIT_BUFFER = 250003
Public Const NITCLK_WARNING_INSTRUMENT_DRIVER_CALL_RETURNED_WARNING = 250004




